FrameClauseDsl

Trait FrameClauseDsl 

pub trait FrameClauseDsl: FrameClauseDslHelper {
    // Provided methods
    fn frame_start_with<E>(self, start: E) -> FrameStartWith<Self, E>
       where E: FrameClauseStartBound { ... }
    fn frame_start_with_exclusion<E1, E2>(
        self,
        start: E1,
        exclusion: E2,
    ) -> FrameStartWithExclusion<Self, E1, E2>
       where E1: FrameClauseStartBound,
             E2: FrameClauseExclusion { ... }
    fn frame_between<E1, E2>(
        self,
        start: E1,
        end: E2,
    ) -> FrameBetween<Self, E1, E2>
       where E1: FrameClauseStartBound,
             E2: FrameClauseEndBound { ... }
    fn frame_between_with_exclusion<E1, E2, E3>(
        self,
        start: E1,
        end: E2,
        exclusion: E3,
    ) -> FrameBetweenWithExclusion<Self, E1, E2, E3>
       where E1: FrameClauseStartBound,
             E2: FrameClauseEndBound,
             E3: FrameClauseExclusion { ... }
}
Construct a frame clause for window functions

Provided Methods

fn frame_start_with<E>(self, start: E) -> FrameStartWith<Self, E>

Construct a frame clause with a starting bound

fn frame_start_with_exclusion<E1, E2>( self, start: E1, exclusion: E2, ) -> FrameStartWithExclusion<Self, E1, E2>

Construct a frame clause with a starting bound and an exclusion condition

fn frame_between<E1, E2>(self, start: E1, end: E2) -> FrameBetween<Self, E1, E2>

Construct a between frame clause with a starting and end bound

fn frame_between_with_exclusion<E1, E2, E3>( self, start: E1, end: E2, exclusion: E3, ) -> FrameBetweenWithExclusion<Self, E1, E2, E3>

Construct a between frame clause with a starting and end bound with an exclusion condition

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> FrameClauseDsl for T
where T: FrameClauseDslHelper,